@@ -82,7 +82,7 @@ semisccs <- function(formula, indiv, astart, aend, aevent, adrug, aedrug, expogr
     aedrug <- aedrug
   }
   
-  # ------------------Getting the fixed covariates from the formula ------------#
+  # ------------------Getting fixed covariates from the formula ------------#
   
   qq <- all.vars(as.formula(formula))[-c(which(all.vars(as.formula(formula))=="event"))]
   
@@ -151,6 +151,10 @@ semisccs <- function(formula, indiv, astart, aend, aevent, adrug, aedrug, expogr
   data1 <- data.frame(unique(cbind(indiv, aevent, astart, aend, cov)))
   data1$astart <- data1$astart-1
   
+  # New 06-11-2021 sorting data1 by indiv
+  data1 <- data1[order(data1$indiv), ]
+  #---------------------------------------# 
+  
   if (dataformat=="stack") {
     # List of all adrug matrices
     adrug_all <- list()
@@ -168,8 +172,22 @@ semisccs <- function(formula, indiv, astart, aend, aevent, adrug, aedrug, expogr
     }
     
   } else if (dataformat=="multi") {
-    adrug_all <- adrug
-    aedrug_all <- aedrug
+   # adrug_all <- adrug
+   # aedrug_all <- aedrug
+    
+    # 06-11-2021 changed the above two lines (184 and 185) as below
+    adrug_all <- list()
+    for (i in 1:length(adrug)) {
+      adrug_all[[i]] <- cbind(indiv, aevent, adrug[[i]])
+      adrug_all[[i]] <- data.frame(adrug_all[[i]][order(adrug_all[[i]][,1],adrug_all[[i]][,3]), -c(1,2)])
+    }
+    aedrug_all <- list()
+    for (i in 1:length(aedrug)) {
+      aedrug_all[[i]] <- cbind(indiv, aevent, aedrug[[i]])
+      aedrug_all[[i]] <- data.frame(aedrug_all[[i]][order(aedrug_all[[i]][,1],aedrug_all[[i]][,3]), -c(1,2)])
+      
+    } 
+    
     
   } else {
     stop("dataformat should be multi or stack")
